..
    :copyright: Copyright (c) 2014 ftrack

.. _release:

***************************
Release and migration notes
***************************

Find out information about what has changed between versions and any important
migration notes to be aware of when switching to a new version.

.. toctree::
    :maxdepth: 1

    release_notes
    migration
    migrating_from_old_api
